diff mercurial/revset.py @ 33776:ed99d3afef88

revset: rename bumped into phasedivergent Don't touch bumped volatile set name, only the revset name. The volatile set name will be updated in a later patch. The renaming is done according to https://www.mercurial-scm.org/wiki/CEDVocabulary. Differential Revision: https://phab.mercurial-scm.org/D252
author Boris Feld <boris.feld@octobus.net>
date Thu, 03 Aug 2017 14:08:39 +0200
parents f078d7358e90
children d4b7496f7d0b
line wrap: on
line diff
--- a/mercurial/revset.py	Thu Aug 03 14:01:51 2017 +0200
+++ b/mercurial/revset.py	Thu Aug 03 14:08:39 2017 +0200
@@ -459,12 +459,20 @@
 
 @predicate('bumped()', safe=True)
 def bumped(repo, subset, x):
+    msg = ("'bumped()' is deprecated, "
+           "use 'phasedivergent()'")
+    repo.ui.deprecwarn(msg, '4.4')
+
+    return phasedivergent(repo, subset, x)
+
+@predicate('phasedivergent()', safe=True)
+def phasedivergent(repo, subset, x):
     """Mutable changesets marked as successors of public changesets.
 
     Only non-public and non-obsolete changesets can be `bumped`.
     """
-    # i18n: "bumped" is a keyword
-    getargs(x, 0, 0, _("bumped takes no arguments"))
+    # i18n: "phasedivergent" is a keyword
+    getargs(x, 0, 0, _("phasedivergent takes no arguments"))
     bumped = obsmod.getrevs(repo, 'bumped')
     return subset & bumped
@@ -459,12 +459,20 @@
     """Mutable changesets marked as successors of public changesets.
 
-    Only non-public and non-obsolete changesets can be `bumped`.
+    Only non-public and non-obsolete changesets can be `phasedivergent`.
     """